""" Constants """

VERSION = 'v2.1.0'
API_PUBLIC_ENDPOINT = 'https://api.softlayer.com/xmlrpc/v3/'
API_PRIVATE_ENDPOINT = 'https://api.service.softlayer.com/xmlrpc/v3/'
API_PRIVATE_ENDPOINT_REST = 'https://api.service.softlayer.com/rest/v3/'
USER_AGENT = "SoftLayer Python %s" % VERSION
